@@ -9,11 +9,8 @@ import (
 	"log"
 	"net/http"
 	"net/url"
-	"os"
-	"os/signal"
 	"strconv"
 	"strings"
-	"syscall"
 	"time"
 
 	"github.com/go-jose/go-jose/v3"
@@ -86,7 +83,8 @@ type ClientConfig struct {
 	TLSCert                string
 	TLSKey                 string
 	TLSRootCA              string
-	Timeout                time.Duration
+	HTTPTimeout            time.Duration
+	BrowserTimeout         time.Duration
 	DPoP                   bool
 	Claims                 string
 	RAR                    string
@@ -279,12 +277,11 @@ func WaitForCallback(clientConfig ClientConfig, serverConfig ServerConfig, hc *h
 		}
 	}()
 
-	signalChan := make(chan os.Signal, 1)
-	signal.Notify(signalChan, syscall.SIGINT, syscall.SIGTERM)
+	timeout := time.After(clientConfig.BrowserTimeout)
 
 	select {
-	case <-signalChan:
-		return request, errors.New("interrupted")
+	case <-timeout:
+		return request, errors.New("timeout")
 	case <-done:
 		return request, err
 	}
